from setuptools import setup, find_packages

setup(
    name = 'mytestlib-sphiarno-88-hello',
    version = '1.0.0',
    url = 'http://localhost',
    author = 'sphiarno-88',
    author_email = 'test@email.com',
    description = 'My Test Library',
    packages = find_packages()
)
